@@ -4,9 +4,10 @@
 import argparse
 import time
 
-from inky.auto import auto
 from PIL import Image
 
+from inky.auto import auto
+
 print("""Inky pHAT: Clean
 
 Displays solid blocks of red, black, and white to clean the Inky pHAT
@@ -18,7 +19,7 @@ inky_display = auto(ask_user=True, verbose=True)
 
 # Command line arguments to determine number of cycles to run
 parser = argparse.ArgumentParser()
-parser.add_argument('--number', '-n', type=int, required=False, help="number of cycles")
+parser.add_argument("--number", "-n", type=int, required=False, help="number of cycles")
 args, _ = parser.parse_known_args()
 
 # The number of red / black / white refreshes to run
