@@ -1,7 +1,9 @@
 #!/usr/bin/env python3
 
 import argparse
+
 from PIL import Image
+
 from inky.auto import auto
 
 print("""Inky wHAT: Dither image
@@ -17,8 +19,8 @@ inky_display.set_border(inky_display.WHITE)
 # Grab the image argument from the command line
 
 parser = argparse.ArgumentParser()
-parser.add_argument('--image', '-i', type=str, required=True, help="Input image to be converted/displayed")
-args = parser.parse_args()
+parser.add_argument("--image", "-i", type=str, required=True, help="Input image to be converted/displayed")
+args, _ = parser.parse_known_args()
 
 img_file = args.image
 
